@@ -371,6 +371,20 @@ connected to two other atoms, "N4" means a nitrogen atom connected to four other
             else:
                 self.atom_marker[atom2][marker] = 1
 
+    def delete_bond(self, atom1, atom2):
+        """
+        This **function** deletes the bond between two atoms
+
+        :param atom1: the index of the first atom
+        :param atom2: the index of the the second atom
+        :return: None
+        """
+        self.bonds[atom1].pop(atom2, None)
+        self.bonds[atom2].pop(atom1, None)
+        self.bond_marker[atom1].pop(atom2, None)
+        self.bond_marker[atom2].pop(atom1, None)
+        
+
     def determine_equal_atoms(self):
         """
         This **function** dertermines the chemical equalvalent atoms
@@ -494,12 +508,9 @@ the rule described in the reference (J. Wang et al., J. Am. Chem. Soc, 2001) wil
         :param penalty_scores: the penalty scores for every atom. This should be a list of ordered dicts, and every
 ordered dict stores the valence-penalty pairs for every atom, and it is sorted by the penalty scores. If None(default),
 a set of penalty scores described in the reference (J. Wang et al., J. Mol. Graph. Model., 2006) will be used.
-        :return: True for success, False for failure.
+        :return: ReasonedBool, True for success, False for failure.
         """
         from .bond_order import BondOrderAssignment
-        if penalty_scores is None:
-            penalty_scores = [BondOrderAssignment.atomic_valence[type_]
-                              for type_ in self.determine_atom_type("bo").values()]
         bo_assign = BondOrderAssignment(penalty_scores, max_step, max_stat, self, debug)
         return bo_assign.main()
 
@@ -753,41 +764,6 @@ def get_assignment_from_residuetype(restype):
     return assign
 
 
-def _deal_with_ar_bonds(assign):
-    """
-
-    :param assign:
-    :return:
-    """
-    ar_bonds_atoms = list(assign.ar_bonds.keys())
-    ar_bonds_atoms.sort(key=lambda x: (x, len(assign.ar_bonds[x])))
-    doubled = Xdict()
-    checked = Xdict()
-    for ar_atom in ar_bonds_atoms:
-        assign.ar_bonds[ar_atom].sort(key=lambda x: (x, len(assign.ar_bonds[x])))
-        doubled[ar_atom] = False
-        checked[ar_atom] = False
-
-    working_space = []
-    while ar_bonds_atoms:
-        working_space.append(ar_bonds_atoms.pop())
-        while working_space:
-            work_atom = working_space.pop()
-            if checked[work_atom]:
-                continue
-            checked[work_atom] = True
-            for neighbor in assign.ar_bonds[work_atom]:
-                if not checked[neighbor]:
-                    working_space.append(neighbor)
-            for neighbor in assign.ar_bonds[work_atom][::-1]:
-                if doubled[work_atom]:
-                    break
-                if not doubled[neighbor] and not doubled[work_atom]:
-                    assign.bonds[neighbor][work_atom] = 2
-                    doubled[neighbor] = True
-                    doubled[work_atom] = True
-
-
 def get_assignment_from_mol2(filename, ignore_hydrogen=False):
     """
     This **function** gets an Assign instance from a mol2 file
@@ -831,7 +807,7 @@ def get_assignment_from_mol2(filename, ignore_hydrogen=False):
                 if words[3] in "1234567890":
                     assign.Add_Bond(atom1 , atom2, int(words[3]))
                 elif words[3] == "ar":
-                    assign.Add_Bond(atom1, atom2, 1)
+                    assign.Add_Bond(atom1, atom2, -1)
                     if atom1 not in assign.ar_bonds.keys():
                         assign.ar_bonds[atom1] = [atom2]
                     else:
@@ -841,7 +817,7 @@ def get_assignment_from_mol2(filename, ignore_hydrogen=False):
                     else:
                         assign.ar_bonds[atom2].append(atom1)
                 elif words[3] == "am":
-                    assign.Add_Bond(atom1, atom2, 1)
+                    assign.Add_Bond(atom1, atom2, -1)
                     if atom1 not in assign.am_bonds.keys():
                         assign.am_bonds[atom1] = [atom2]
                     else:
@@ -853,7 +829,9 @@ def get_assignment_from_mol2(filename, ignore_hydrogen=False):
                 else:
                     raise NotImplementedError(f"No implemented method to process bond #{words[0]} type {words[3]}")
 
-    _deal_with_ar_bonds(assign)
+    success = assign.Determine_Bond_Order()
+    if not success:
+        raise ValueError("Failed to determine the bond orders")
     assign.Determine_Ring_And_Bond_Type()
     return assign
 
